function [u,new_xmin,new_xmax] = prctball(x,pr,sf)
%
% Rescale data to unit sphere, except possibly for extreme outliers
% Data outside the unit sphere considered extreme outliers
%
% x = data
% pr = percentage of data guaranteed to be in box
% sf = scaling factor: a point is an outlier if it exceeds the chosen
% percentile by more than sf times the distance between that percentile and
% the center of the sphere
%
% u = normalized data; thus extreme outliers are those
% points outside the unit cube after scaling
%

n = size(x,2);
xmed = median(x,2);

rad_pr = prctile(sqrt(sum((x-repmat(xmed,1,n)).^2)),100*pr);

u = (x-repmat(xmed,1,n))/(rad_pr*(1+sf));


