function [u,new_xmin,new_xmax] = prctbox(x,pr,sf)
%
% Rescale data to unit hypercube, except possibly for extreme outliers
% draw a box around data so as to remove extreme outliers.
%
% x = data
% pr = percentage of data along each coordinate that is guaranteed to be in box
% sf = scaling factor: a point is an outlier if it exceeds the nearest
% (minimum or maximum) percentile by more than sf times the distance between that percentile and
% the median
%
% u = data scaled so that box is unit cube; thus extreme outliers are those
% points outside the unit cube after scaling
%

n = size(x,2);

xmed = median(x,2);

xpmin = prctile(x,100*(1/2-pr/2),2);
xpmax = prctile(x,100*(1/2+pr/2),2);

new_xmin = xpmin - sf*(xmed - xpmin);
new_xmax = xpmax + sf*(xpmax - xmed);
width = (new_xmax - new_xmin);

u=(x-repmat(new_xmin,[1,n]))./repmat(width,[1,n]);

